# API Reference

```{eval-rst}
.. currentmodule:: array_api_extra
.. autosummary::
    :nosignatures:
    :toctree: generated

    apply_where
    at
    atleast_nd
    broadcast_shapes
    cov
    create_diagonal
    expand_dims
    isclose
    kron
    nunique
    pad
    setdiff1d
    sinc
```
